@@ -1,4 +1,4 @@
-from .http import HTTPClient, Route
+from .http import File, HTTPClient, Route
 from .ws import GatewayClient, Shard
 from .errors import (
     CordedError,
@@ -12,11 +12,12 @@ from .errors import (
     DiscordServerError,
 )
 from .constants import VERSION as __version__
-from .objects import Object
+from .objects import Object, GatewayEvent, Intents
 from .client import CordedClient
 from .helpers import BitField
 
 __all__ = (
+    File,
     HTTPClient,
     Route,
     CordedError,
@@ -29,9 +30,11 @@ __all__ = (
     TooManyRequests,
     DiscordServerError,
     Object,
+    GatewayEvent,
     GatewayClient,
     Shard,
     CordedClient,
     BitField,
+    Intents,
     __version__,
 )
