@@ -23,19 +23,34 @@ SOFTWARE.
 """
 
 from asyncio import AbstractEventLoop, get_event_loop, sleep
-from aiohttp import ClientSession, ClientResponse
+from aiohttp import ClientSession, ClientResponse, FormData
+from json import JSONDecodeError
+from typing import Any, Literal
 
 from corded.constants import API_URL, VERSION
-from corded.errors import HTTPError, BadRequest, Unauthorized, Forbidden, NotFound, PayloadTooLarge, TooManyRequests, DiscordServerError
+from corded.errors import (
+    HTTPError,
+    BadRequest,
+    Unauthorized,
+    Forbidden,
+    NotFound,
+    PayloadTooLarge,
+    TooManyRequests,
+    DiscordServerError,
+)
 
+from .file import File
 from .ratelimiter import Ratelimiter
 from .route import Route
 
 import corded.objects.partials as p
 
 
+ResponseFormat = Literal["raw", "text", "json", "auto", "response"]
+
+
 class HTTPClient:
-    def __init__(self, token: str, *, url: str = None, loop: AbstractEventLoop = None):
+    def __init__(self, token: str, *, url: str = None, loop: AbstractEventLoop = None) -> None:
         """An HTTP client to make Discord API requests, observing ratelimits.
 
         Args:
@@ -67,7 +82,7 @@ class HTTPClient:
         }
 
     @staticmethod
-    async def response_as(response: ClientResponse, format: str = None):
+    async def response_as(response: ClientResponse, format: ResponseFormat = "json") -> Any:
         """Return a ClientResponse in a given format.
 
         Args:
@@ -84,13 +99,21 @@ class HTTPClient:
         if format == "auto":
             try:
                 return await response.json()
-            except:
+            except JSONDecodeError:
                 return await response.text()
         if format == "response":
             return response
         raise ValueError("Format must be one of 'json', 'text', 'auto', 'raw'")
 
-    async def request(self, method: str, route: Route, *, attempts: int = None, expect: str = None, **params):
+    async def request(
+        self,
+        method: str,
+        route: Route,
+        *,
+        attempts: int = None,
+        expect: ResponseFormat = "json",
+        **params,
+    ) -> Any:
         """Make a Discord API request.
 
         Args:
@@ -101,27 +124,48 @@ class HTTPClient:
         """
 
         attempts = attempts or 3
-        expect = expect or "json"
 
         if not self.session or self.session.closed:
             self.session = ClientSession(headers=self.headers)
 
         bucket = route.bucket
 
-        headers = {}
+        request_headers = {}
         if "reason" in params:
-            headers["X-Audit-Log-Reason"] = params.pop("reason")
+            request_headers["X-Audit-Log-Reason"] = params.pop("reason")
 
         for i in range(attempts):
+            if files := params.pop("files", []):
+                if i:
+                    for file in files:
+                        file.seek(0)
+                formdata = FormData()
+
+                for fn, file in enumerate(files):
+                    if not isinstance(file, File):
+                        raise TypeError(
+                            f"files must be a list of corded.File, not {file.__class__.__qualname__}"
+                        )
+                    formdata.add_field(f"file_{fn}", file.file, filename=file.filename)
+
+                for k, v in params.pop("json", {}).items():
+                    formdata.add_field(k, v)
+
+                params["data"] = formdata
+
             await self.ratelimiter.acquire(bucket)
 
-            response = await self.session.request(method, self.url + route.route, **params)
+            response = await self.session.request(
+                method, self.url + route.route, headers=request_headers, **params
+            )
 
             status = response.status
             headers = response.headers
 
             rl_reset_after = float(headers.get("X-RateLimit-Reset-After", 0))
-            rl_bucket_remaining = int(headers.get("X-RateLimit-Remaining", 1))  # Default here is for non authenticated (and hence non ratelimited) endpoints
+
+            # Default here is for non authenticated (and hence non ratelimited) endpoints
+            rl_bucket_remaining = int(headers.get("X-RateLimit-Remaining", 1))
             rl_sleep_for = 0
 
             if status != 429 and rl_bucket_remaining == 0:
@@ -170,14 +214,12 @@ class HTTPClient:
             "max_msg_size": 0,
             "timeout": 60,
             "autoclose": False,
-            "headers": {
-                "User-Agent": self.headers["User-Agent"]
-            },
+            "headers": {"User-Agent": self.headers["User-Agent"]},
         }
 
         return await self.session.ws_connect(url, **args)
 
-    async def close(self):
+    async def close(self)  -> None:
         await self.session.close()
 
     async def get_gateway(self) -> p.GetGateway:
