@@ -23,8 +23,7 @@ SOFTWARE.
 """
 
 from .base import Object
+from .gateway import GatewayEvent, Intents
 
 
-__all__ = (
-    Object,
-)
+__all__ = (Object, GatewayEvent, Intents)
